@@ -247,7 +247,7 @@ class ControlPoint:
         await asyncio.sleep(ControlPointProtocol.DEVICE_GET_TIMEOUT)
 
     async def __get_states(self):
-        '''Get latest state data from controller.'''
+        '''Get latest state data from controller and reset watchdog.'''
 
         self.states_ready = self.loop.create_future()
 
@@ -261,6 +261,9 @@ class ControlPoint:
             raise ControlPointError(
                 "ZCC connection failed - didn't receive updated states.") from error
 
+        if self.watchdog_timer:
+            self.watchdog_timer.reset()
+
     def print_description(self):
         '''Print description of the ZCC controller.'''
         print(self.describe())
